package com.ruoyi.bar.mapper;

import com.ruoyi.common.core.domain.entity.WyBarUser;

import java.util.List;

/**
 * 品牌方用户信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-01-04
 */
public interface WyBarUserMapper 
{
    /**
     * 查询品牌方用户信息
     * 
     * @param userId 品牌方用户信息主键
     * @return 品牌方用户信息
     */
    public WyBarUser selectWyBarUserByUserId(Long userId);
    public WyBarUser selectWyBarUserByUserName(String userName);
    public WyBarUser selectWyBarUserByPhoneNumber(String phonenumber);
    public WyBarUser selectWyBarUserByOpenId(String openId);

    /**
     * 查询品牌方用户信息列表
     * 
     * @param wyBarUser 品牌方用户信息
     * @return 品牌方用户信息集合
     */
    public List<WyBarUser> selectWyBarUserList(WyBarUser wyBarUser);

    /**
     * 新增品牌方用户信息
     * 
     * @param wyBarUser 品牌方用户信息
     * @return 结果
     */
    public int insertWyBarUser(WyBarUser wyBarUser);

    /**
     * 修改品牌方用户信息
     * 
     * @param wyBarUser 品牌方用户信息
     * @return 结果
     */
    public int updateWyBarUser(WyBarUser wyBarUser);

    /**
     * 删除品牌方用户信息
     * 
     * @param userId 品牌方用户信息主键
     * @return 结果
     */
    public int deleteWyBarUserByUserId(Long userId);

    /**
     * 批量删除品牌方用户信息
     * 
     * @param userIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyBarUserByUserIds(Long[] userIds);
}
