package com.ruoyi.web.controller.bar;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.WyBarUser;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.bar.service.IWyBarUserService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 品牌方用户信息Controller
 * 
 * @author ruoyi
 * @date 2025-01-04
 */
@RestController
@RequestMapping("/system/bar/barUser")
public class WyBarUserController extends BaseController
{
    @Autowired
    private IWyBarUserService wyBarUserService;

    /**
     * 查询品牌方用户信息列表
     */
    @PreAuthorize("@ss.hasPermi('bar:barUser:list')")
    @GetMapping("/list")
    public TableDataInfo list(WyBarUser wyBarUser)
    {
        startPage();
        List<WyBarUser> list = wyBarUserService.selectWyBarUserList(wyBarUser);
        return getDataTable(list);
    }

    /**
     * 导出品牌方用户信息列表
     */
    @PreAuthorize("@ss.hasPermi('bar:barUser:export')")
    @Log(title = "品牌方用户信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WyBarUser wyBarUser)
    {
        List<WyBarUser> list = wyBarUserService.selectWyBarUserList(wyBarUser);
        ExcelUtil<WyBarUser> util = new ExcelUtil<WyBarUser>(WyBarUser.class);
        util.exportExcel(response, list, "品牌方用户信息数据");
    }

    /**
     * 获取品牌方用户信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('bar:barUser:query')")
    @GetMapping(value = "/{userId}")
    public AjaxResult getInfo(@PathVariable("userId") Long userId)
    {
        return success(wyBarUserService.selectWyBarUserByUserId(userId));
    }

    /**
     * 新增品牌方用户信息
     */
    @PreAuthorize("@ss.hasPermi('bar:barUser:add')")
    @Log(title = "品牌方用户信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WyBarUser wyBarUser)
    {
        return toAjax(wyBarUserService.insertWyBarUser(wyBarUser));
    }

    /**
     * 修改品牌方用户信息
     */
    @PreAuthorize("@ss.hasPermi('bar:barUser:edit')")
    @Log(title = "品牌方用户信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WyBarUser wyBarUser)
    {
        return toAjax(wyBarUserService.updateWyBarUser(wyBarUser));
    }

    /**
     * 删除品牌方用户信息
     */
    @PreAuthorize("@ss.hasPermi('bar:barUser:remove')")
    @Log(title = "品牌方用户信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{userIds}")
    public AjaxResult remove(@PathVariable Long[] userIds)
    {
        return toAjax(wyBarUserService.deleteWyBarUserByUserIds(userIds));
    }
}
